@@ -17,24 +17,26 @@ pub mod primitives {
         // impliments equation 14a in reference paper.
         fn get_axial_field(&self, z: &f64, r: &f64, tol: &f64) -> f64 {
             let mut answer = 0.0;
-            for counter in 0..self.get_max_depth() {
+            let mut counter = 0;
+            let mut diff = 1.0;
+            while diff > *tol && counter < self.get_max_depth() {
                 let old_answer = answer;
                 let next_derivative = self.get_nth_derivative(&(2 * counter as u32), &z);
                 let denominator = f64::powi(2.0, 2 * counter as i32)
                     * ((factorial(counter as u32) * factorial(counter as u32)) as f64);
                 let numerator =
                     i32::pow(-1, counter as u32) as f64 * f64::powi(*r, 2 * counter as i32);
+                counter += 1;
                 answer += next_derivative * numerator / denominator;
-                let diff = f64::abs((answer - old_answer) / old_answer);
-                if diff < *tol {
-                    break;
-                }
+                diff = f64::abs(answer - old_answer);
             }
             answer
         }
         fn get_radial_field(&self, z: &f64, r: &f64, tol: &f64) -> f64 {
             let mut answer = 0.0;
-            for counter in 0..self.get_max_depth() {
+            let mut counter = 0;
+            let mut diff = 1.0;
+            while diff > *tol && counter < self.get_max_depth() {
                 let old_answer = answer;
                 let next_derivative = self.get_nth_derivative(&(1 + 2 * counter as u32), &z);
                 let denominator = f64::powi(2.0, (2 * counter + 1) as i32)
@@ -42,10 +44,8 @@ pub mod primitives {
                 let numerator = i32::pow(-1, 1 + counter as u32) as f64
                     * f64::powi(*r, (2 * counter + 1) as i32);
                 answer += next_derivative * numerator / denominator;
-                let diff = f64::abs((answer - old_answer) / old_answer);
-                if diff < *tol {
-                    break;
-                }
+                counter += 1;
+                diff = f64::abs(answer - old_answer);
             }
             answer
         }
